@@ -1429,6 +1429,14 @@ globus_ftp_control_server_listen(
     globus_ftp_control_server_callback_t	callback,
     void *					callback_arg);
 
+globus_result_t
+globus_ftp_control_server_listen_ex(
+    globus_ftp_control_server_t *		handle,
+    globus_io_attr_t *				attr,
+    unsigned short *				port,
+    globus_ftp_control_server_callback_t	callback,
+    void *					callback_arg);
+
 globus_result_t
 globus_ftp_control_server_stop(
     globus_ftp_control_server_t *		listener,
@@ -1766,6 +1774,11 @@ globus_ftp_control_data_get_socket_buf(
     int *                               rcvbuf,
     int *                               sndbuf);
 
+globus_result_t
+globus_ftp_control_data_get_retransmit_count(
+    globus_ftp_control_handle_t *       handle,
+    char **                             retransmit_count);
+
 #ifdef __cplusplus
 }
 #endif
